package uk.co.wobblycogs.samplefx4;

import java.io.IOException;
import java.io.Serializable;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;

/**
 * A handy base class for persistence services. The basic operations (with the
 * exception of persist) are handled in a generic way. Implementing classes
 * simply need to add on any additional queries required.
 *
 * @param <T>
 * @author Graham Smith
 */
public abstract class AbstractService<T extends Serializable> implements Service<T> {

	protected EntityManagerFactory emf;

	public AbstractService(String persistenceUnitName) throws IOException {
		emf = PersistenceUtilities.getInstance().getEntityManagerFactory(persistenceUnitName, null);
	}

	@Override
	public void remove(T item) {
		EntityManager em = emf.createEntityManager();
		em.getTransaction().begin();
		em.remove(em.merge(item));
		em.getTransaction().commit();
		em.close();
	}

	@Override
	public void persist(T item) {
		EntityManager em = emf.createEntityManager();
		em.getTransaction().begin();
		em.persist(item);
		em.getTransaction().commit();
		em.close();
	}

	@Override
	public T merge(T item) {
		EntityManager em = emf.createEntityManager();
		em.getTransaction().begin();
		T merged = em.merge(item);
		em.getTransaction().commit();
		em.close();
		return merged;
	}
}
