/*
 * Copyright 2013 Graham Smith
 */
package uk.co.wobblycogs.samplefx4;

import java.io.IOException;

/**
 * Simply generates some demonstration data. This is called from the
 * {@code Demo} class and can be commented out.
 *
 * @author Graham Smith
 */
public class DemoDataGenerator {

	public DemoDataGenerator() {
	}

	public void generate() throws IOException {
		DepartmentService departmentService = new DepartmentService(Demo.PERSISTENCE_UNIT_NAME);
		PersonService personService = new PersonService(Demo.PERSISTENCE_UNIT_NAME);

		Department wholeCompany = departmentService.findRoot();

		//Relies on the cascade delete functionality of the department class.
		if (wholeCompany != null) {
			departmentService.remove(wholeCompany);
			personService.deleteAll();
		}

		//Generating a new root
		wholeCompany = new Department();
		wholeCompany.setName("Whole Company");
		departmentService.persist(wholeCompany);

		Department softwareDepartment = new Department();
		softwareDepartment.setName("Software");
		departmentService.persist(softwareDepartment);
		departmentService.addChildDepartment(wholeCompany, softwareDepartment);

		Department operatingSystemsDepartment = new Department();
		operatingSystemsDepartment.setName("Operating Systems");
		departmentService.persist(operatingSystemsDepartment);
		departmentService.addChildDepartment(softwareDepartment, operatingSystemsDepartment);

		Department languageDepartment = new Department();
		languageDepartment.setName("Programming Languages");
		departmentService.persist(languageDepartment);
		departmentService.addChildDepartment(softwareDepartment, languageDepartment);

		Department hardwareDepartment = new Department();
		hardwareDepartment.setName("Hardware");
		departmentService.persist(hardwareDepartment);
		departmentService.addChildDepartment(wholeCompany, hardwareDepartment);

		Department internetDepartment = new Department();
		internetDepartment.setName("Internet / Web");
		departmentService.persist(internetDepartment);
		departmentService.addChildDepartment(wholeCompany, internetDepartment);


		addPerson("Charles Babbage", hardwareDepartment, personService, departmentService);
		addPerson("John von Neumann", hardwareDepartment, personService, departmentService);
		addPerson("Ada Lovelace", softwareDepartment, personService, departmentService);
		addPerson("Alan Turing", softwareDepartment, personService, departmentService);
		addPerson("Linus Torvalds", operatingSystemsDepartment, personService, departmentService);
		addPerson("James Gosling", languageDepartment, personService, departmentService);
		personService.persist(new Person("Tim Berners-Lee"));
		personService.persist(new Person("Vint Cerf"));
		personService.persist(new Person("Andrew S. Tanenbaum"));
	}

	private void addPerson(String name, Department department, PersonService personService, DepartmentService departmentService) {
		Person p = new Person(name);
		personService.persist(p);
		departmentService.addPerson(department, p);

	}
}
