/*
 * Copyright 2013 Graham Smith
 */
package uk.co.wobblycogs.samplefx4;

import java.io.Serializable;
import java.util.List;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.TableGenerator;
import javax.persistence.UniqueConstraint;

/**
 * Representation of a department where zero or more people work. Departments
 * can have sub-departments. The root of the department tree is the whole
 * company and is located by finding a department with no parent.
 *
 * @author Graham Smith
 */
@Entity
@Table(name = "DEPT")
@NamedQueries({
	@NamedQuery(name = Department.FIND_ALL, query = "SELECT d FROM Department d"),
	@NamedQuery(name = Department.FIND_ROOT, query = "SELECT d FROM Department d WHERE d.parent IS NULL")
})
public class Department implements Serializable {

	public static final String FIND_ALL = "uk.co.wobblycogs.samplefx4.Department.findAll";
	public static final String FIND_ROOT = "uk.co.wobblycogs.samplefx4.Department.findRoot";
	@Id
	@GeneratedValue
	private long id;
	@Column(unique = true)
	private String name;
	@OneToMany(mappedBy = "department", cascade = CascadeType.ALL)
	private List<Person> personnel;
	@ManyToOne
	private Department parent;
	@OneToMany(mappedBy = "parent", cascade = CascadeType.ALL)
	private List<Department> children;

	public Department() {
	}

	public long getId() {
		return id;
	}

	public void setId(long id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public List<Person> getPersonnel() {
		return personnel;
	}

	public void setPersonnel(List<Person> personnel) {
		this.personnel = personnel;
	}

	public void addPerson(Person person) {
		this.personnel.add(person);
	}

	public Department getParent() {
		return parent;
	}

	public void setParent(Department parent) {
		this.parent = parent;
	}

	public List<Department> getChildren() {
		return children;
	}

	public void setChildren(List<Department> children) {
		this.children = children;
	}

	public void addChild(Department department) {
		this.children.add(department);
	}

	@Override
	public String toString() {
		return getName();
	}
}
