/*
 * Copyright 2013 Graham Smith
 */
package uk.co.wobblycogs.samplefx4;

import java.io.IOException;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.Query;
import javax.persistence.TypedQuery;

/**
 * Handles persistence services required by a {@code Department}/
 *
 * @author Graham Smith
 */
public class DepartmentService extends AbstractService<Department> {

	public DepartmentService(String persistenceUnitName) throws IOException {
		super(persistenceUnitName);
	}

	@Override
	public Department find(Long id) {
		EntityManager em = emf.createEntityManager();
		return em.find(Department.class, id);
	}

	public List<Department> findAll() {
		EntityManager em = emf.createEntityManager();
		Query q = em.createNamedQuery(Department.FIND_ALL);
		List<Department> results = q.getResultList();
		return results;
	}

	public Department findRoot() {
		EntityManager em = emf.createEntityManager();
		TypedQuery<Department> query = em.createNamedQuery(Department.FIND_ROOT, Department.class);
		List<Department> results = query.getResultList();
		if (results.isEmpty()) {
			return null;
		}
		return results.get(0);
	}

	/**
	 * Adds the child department to the parent department and then merges the
	 * result.
	 * <p>
	 * Note that this method uses a merge operation so both the parent and child
	 * departments must already be known to the system e.g. they have already
	 * been persisted. This is because merge gives back a new copy of an object
	 * even if it actually performs a persist operation. It is the callers
	 * responsibility to ensure that newly created departments
	 *
	 * @param parent
	 * @param child
	 */
	public void addChildDepartment(Department parent, Department child) {
		EntityManager em = emf.createEntityManager();
		em.getTransaction().begin();

		child.setParent(parent);
		parent.addChild(child);
		em.merge(parent);
		em.merge(child);

		em.getTransaction().commit();
	}

	public void addPerson(Department deparment, Person person) {
		EntityManager em = emf.createEntityManager();
		em.getTransaction().begin();

		deparment.addPerson(person);
		person.setDepartment(deparment);
		em.merge(deparment);
		em.merge(person);

		em.getTransaction().commit();
	}
}
