/*
 * Copyright 2013 Graham Smith
 */
package uk.co.wobblycogs.samplefx4;

import java.io.Serializable;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;

/**
 * Represents a person. Each person is assigned to zero or one department.
 * People who are assigned to no department are considered unassigned.
 *
 * @author Graham Smith
 */
@Entity
@Table(name = "PERSON ")
@NamedQueries({
	@NamedQuery(name = Person.FIND_ALL, query = "SELECT p FROM Person p"),
	@NamedQuery(name = Person.FIND_UNASSIGNED, query = "SELECT p FROM Person p WHERE p.department IS NULL"),
	@NamedQuery(name = Person.DELETE_ALL, query = "DELETE FROM Person p")
})
public class Person implements Serializable {

	public static final String FIND_ALL = "uk.co.wobblycogs.samplefx4.Person.findAll";
	public static final String FIND_UNASSIGNED = "uk.co.wobblycogs.samplefx4.Person.findUnassigned";
	public static final String DELETE_ALL = "uk.co.wobblycogs.samplefx4.Person.deleteAll";

	public Person() {
	}

	public Person(String name) {
		this.name = name;
	}
	@Id
	@GeneratedValue
	private long id;
	private String name;
	@ManyToOne
	private Department department;

	public long getId() {
		return id;
	}

	public void setId(long id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Department getDepartment() {
		return department;
	}

	public void setDepartment(Department department) {
		this.department = department;
	}

	@Override
	public String toString() {
		return getName();
	}
}
